import { select } from 'd3';

const svg = d3.select('svg');
const arena = svg.append('circle');
const arenaN = svg.append('circle');
const arenaNStart = svg.append('circle');

const height = svg.attr('height');
const width = svg.attr('width');

const topMargin = 50;
const bottomMargin = 50;
const leftMargin = 100;
const rightMargin = 50;
const horizontalMargin = leftMargin + rightMargin;
const verticalMargin = topMargin + bottomMargin;
const innerWidth = width - horizontalMargin;
const innerHeight = height - verticalMargin;

const cx = leftMargin + innerWidth / 2;
const cy = topMargin + innerHeight / 2;

const starStartProportion = .5;
const starProportion = .8;
const planetProportion = 1;
const planetStartProportion = .8;

const r = Math.min(innerWidth, innerHeight) / 2;

const data = [["Su"], [], ["Ra", "Ke"], [], ["Ve"], ["Me"], ["Sa", "Ju"], [], [], ["Mo"], [], ["Ne"]];

arena.attr('fill', 'lightpink')
  .attr('height', height)
	.attr('width', width)
	.attr('cy', cy)
	.attr('cx', cx)
  .attr('r', r*planetProportion)
	.attr('stroke-width', 1)
	.attr('stroke', 'grey');

arenaN.attr('fill', 'lightblue')
	.attr('cy', cy)
	.attr('cx', cx)
  .attr('r', r*starProportion)
	.attr('stroke-width', 1)
	.attr('stroke', 'grey');

arenaNStart.attr('fill', 'white')
  .attr('cy', cy)
	.attr('cx', cx)
  .attr('r', r*starStartProportion)
	.attr('stroke-width', 1)
	.attr('stroke', 'grey');

var chart = svg.append('g')
 .attr("stroke-width", 1)
 .attr("stroke", "grey");

const symbols = {"Su": "\u2609", "Mo": "\u263D", "Me": "\u263F", "Ve": "\u2640", "Ea": "\u2641", "Ma": "\u2642", "Ju": "\u2643", "Sa": "\u2644", "Ur": "\u26E2", "Ne": "\u2646"};

const stars = d3.range(27);

function d2r(d) {
  if(d > 360)
    d = d - 360;
	return d * Math.PI / 180;
}

stars.forEach(function(s, i){
	var angleOffset = d2r(180/27);
  var angle = -i * d2r(360/27);
  var x1 = cx + Math.sin(angle) * r*starStartProportion;
	var y1 = cy + Math.cos(angle) * r*starStartProportion;
  var x2 = cx + Math.sin(angle) * r*starProportion;
	var y2 = cy + Math.cos(angle) * r*starProportion;
	chart.append('line')
  	.attr('x1', x1)
  	.attr('y1', y1)
	  .attr('x2', x2)
  	.attr('y2', y2)
  	.attr('stroke', 'brown')
  	.attr('stroke-width', 'thin');
});

console.log(stars);

data.forEach(function(v, i) {
  var value = v.map(function(p) {
  	return symbols[p];
  }).join('');
  var angleOffset = d2r(15);
  var angle = -i * d2r(30);
  var textR = r-20;
  var x = cx + Math.sin(angle) * r;
	var y = cy + Math.cos(angle) * r;
  var fromX = cx + Math.sin(angle) * (r * planetStartProportion);
	var fromY = cy + Math.cos(angle) * (r * planetStartProportion);
  var rotate = angle-angleOffset;
  
  var textX = cx + Math.sin(rotate) * textR;
	var textY = cy + Math.cos(rotate) * textR;

  var labelX = cx + Math.sin(rotate) * (r+20);
	var labelY = cy + Math.cos(rotate) * (r+20);

  chart.append('line')
  	.attr('x1', fromX)
    .attr('y1', fromY)
  	.attr('x2', x)
    .attr('y2', y)
    .style('stroke', 'gray');
  showText(i+1, value, textX, textY, rotate);
  showText(i+1, getOrdinal(i+1), labelX, labelY, rotate);
});

function getOrdinal(n) {   
	if(n==11 || n==12 || n==13)
      return n+"th";

  switch(n%10) {
    case 1:
    	return n + "st";
    	break;
    case 2:
    	return n + "nd";
    	break;
    case 3:
    	return n + "rd";
    	break;
    default:
    	return n + "th";
    	break;
  }
}

function showText(house, text, x, y, rotate) {
  var item = svg.append('text')
    .attr('x', x)
  	.attr('y', y)
  	.attr('text-anchor', 'middle')
  	.attr('alignment-baseline', 'middle');
  item.style('font-family', 'sans-serif')
  	.style('font-size', '11px');
  item.text(text);
}